Class: Prawn::Table::Cell

Inherits:
Object
  • Object
show all
Defined in:
lib/prawn/accessibility/table.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#is_header_cellObject

Whether this cell is a header cell (TH) for accessibility. Set automatically for cells in header rows when the table has header: true.



131
132
133
# File 'lib/prawn/accessibility/table.rb', line 131

def is_header_cell
  @is_header_cell
end

Instance Method Details

#draw_content_only(pt) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Draws only the cell content (no borders or background). Used by the tagged PDF rendering path where borders are drawn separately as artifacts.



145
146
147
# File 'lib/prawn/accessibility/table.rb', line 145

def draw_content_only(pt)
  draw_bounded_content(pt)
end

#header?Boolean

Whether this cell is a header cell.

Returns:

  • (Boolean)


136
137
138
# File 'lib/prawn/accessibility/table.rb', line 136

def header?
  !!@is_header_cell
end